<?php

// Database Parameters
$cfgHostname = '[[softdbhost]]';
$cfgDatabase = '[[softdb]]';
$cfgUsername = '[[softdbuser]]';
$cfgPassword = '[[softdbpass]]';
$cfgSqlType = 'mysql';
$cfgPrefix = 'planning_';
?>